@@ -1,10 +1,6 @@
 from bfg.module import Module as BLModule
 from bfg.args.testing import default
 
-# ==================
-# BUILD THE CALLBACK
-# ==================
-
 class Module(BLModule):
     '''Fake authentication callback for testing purposes. Accepts a
     username and password value during initialization that will be
@@ -14,7 +10,6 @@ class Module(BLModule):
     an authentication event during tool development.
     '''
 
-    name = 'Fake'
     description = brief_description = 'Fake authentication module for ' \
             'training/testing'
     args = default()
@@ -26,7 +21,6 @@ class Module(BLModule):
                     twitter='@ImposterKeanu'))
         ]
 
-
     def __init__(self, username:str, password:str):
         '''Initialize the Fake object.
 
